@@ -6,6 +6,7 @@ package Verilog::Netlist::Interface;
 use Class::Struct;
 
 use Verilog::Netlist;
+use Verilog::Netlist::ModPort;
 use Verilog::Netlist::Net;
 use Verilog::Netlist::Pin;
 use Verilog::Netlist::Subclass;
@@ -14,7 +15,7 @@ use strict;
 @ISA = qw(Verilog::Netlist::Interface::Struct
 	Verilog::Netlist::Subclass);
 
-$VERSION = '3.223';
+$VERSION = '3.230';
 
 structs('new',
 	'Verilog::Netlist::Interface::Struct'
@@ -26,10 +27,11 @@ structs('new',
 	   attributes	=> '%', #'	# Misc attributes for systemperl or other processors
 	   #
 	   comment	=> '$', #'	# Comment provided by user
+	   _cells	=> '%',		# hash of Verilog::Netlist::Cells
+	   _modports    => '%',		# hash of Verilog::Netlist::ModPorts
 	   _ports	=> '%',		# hash of Verilog::Netlist::Ports
 	   _portsordered=> '@',		# list of Verilog::Netlist::Ports as ordered in list of ports
 	   _nets	=> '%',		# hash of Verilog::Netlist::Nets
-	   _cells	=> '%',		# hash of Verilog::Netlist::Cells
 	   _level	=> '$',		# Depth in hierarchy (if calculated)
 	   ]);
 
@@ -41,6 +43,9 @@ sub delete {
     foreach my $oref ($self->ports) {
 	$oref->delete;
     }
+    foreach my $oref ($self->modports) {
+	$oref->delete;
+    }
     foreach my $oref ($self->cells) {
 	$oref->delete;
     }
@@ -59,6 +64,11 @@ sub logger {
     return $_[0]->netlist->logger;
 }
 
+sub find_modport {
+    my $self = shift;
+    my $search = shift;
+    return $self->_modports->{$search} || $self->_modports->{"\\".$search." "};
+}
 sub find_port {
     my $self = shift;
     my $search = shift;
@@ -88,6 +98,18 @@ sub find_net {
 sub attrs_sorted {
     return (sort {$a cmp $b} @{$_[0]->attrs});
 }
+sub cells {
+    return (values %{$_[0]->_cells});
+}
+sub cells_sorted {
+    return (sort {$a->name() cmp $b->name()} (values %{$_[0]->_cells}));
+}
+sub modports {
+    return (values %{$_[0]->_modports});
+}
+sub modports_sorted {
+    return (sort {$a->name() cmp $b->name()} (values %{$_[0]->_modports}));
+}
 sub nets {
     return (values %{$_[0]->_nets});
 }
@@ -104,12 +126,7 @@ sub ports_ordered {
     my $self = shift;
     return map {$self->_ports->{$_}} @{$self->_portsordered};
 }
-sub cells {
-    return (values %{$_[0]->_cells});
-}
-sub cells_sorted {
-    return (sort {$a->name() cmp $b->name()} (values %{$_[0]->_cells}));
-}
+
 sub nets_and_ports_sorted {
     return Verilog::Netlist::Module::nets_and_ports_sorted(@_);
 }
@@ -131,6 +148,14 @@ sub new_attr {
     push @{$self->attrs}, $clean_text;
 }
 
+sub new_modport {
+    my $self = shift;
+    # @_ params
+    my $oref = new Verilog::Netlist::ModPort (@_, module=>$self,);
+    $self->_modports ($oref->name(), $oref);
+    return $oref;
+}
+
 sub new_port {
     my $self = shift;
     # @_ params
@@ -167,6 +192,9 @@ sub link {
     foreach my $netref ($self->nets) {
 	$netref->_link();
     }
+    foreach my $oref ($self->modports) {
+	$oref->_link();
+    }
     foreach my $cellref ($self->cells) {
 	$cellref->_link();
     }
@@ -200,11 +228,12 @@ sub verilog_text {
     }
     push @out, ");\n";
 
-    # Signal list
     foreach my $netref ($self->nets_sorted) {
 	push @out, $indent, $netref->verilog_text, "\n";
     }
-    # Cell list
+    foreach my $oref ($self->modports_sorted) {
+	push @out, $indent, $oref->verilog_text, "\n";
+    }
     foreach my $cellref ($self->cells_sorted) {
 	push @out, $indent, $cellref->verilog_text, "\n";
     }
@@ -225,6 +254,9 @@ sub dump {
 	foreach my $netref ($self->nets_sorted) {
 	    $netref->dump($indent+2);
 	}
+	foreach my $oref ($self->modports_sorted) {
+	    $oref->dump($indent+2);
+	}
 	foreach my $cellref ($self->cells_sorted) {
 	    $cellref->dump($indent+2);
 	}
@@ -272,6 +304,15 @@ passed to Verilog::Netlist::new for comments to be retained.
 
 Returns the port name associated with the given index.
 
+=item $self->modports
+
+Returns list of references to Verilog::Netlist::ModPort in the interface.
+
+=item $self->modports_sorted
+
+Returns list of references to Verilog::Netlist::ModPort in the interface
+sorted by name.
+
 =item $self->name
 
 The name of the interface.
@@ -286,7 +327,8 @@ Returns list of references to Verilog::Netlist::Net in the interface.
 
 =item $self->nets_sorted
 
-Returns list of name sorted references to Verilog::Netlist::Net in the interface.
+Returns list of name sorted references to Verilog::Netlist::Net in the
+interface.
 
 =item $self->nets_and_ports_sorted
 
@@ -295,17 +337,17 @@ Verilog::Netlist::Port in the interface.
 
 =item $self->ports
 
-Returns list of references to Verilog::Netlist::Port in the module.
+Returns list of references to Verilog::Netlist::Port in the interface.
 
 =item $self->ports_ordered
 
-Returns list of references to Verilog::Netlist::Port in the module sorted
-by pin number.
+Returns list of references to Verilog::Netlist::Port in the interface
+sorted by pin number.
 
 =item $self->ports_sorted
 
-Returns list of references to Verilog::Netlist::Port in the module sorted
-by name.
+Returns list of references to Verilog::Netlist::Port in the interface
+sorted by name.
 
 =back
 
@@ -357,7 +399,7 @@ Verilog-Perl is part of the L<http://www.veripool.org/> free Verilog EDA
 software tool suite.  The latest version is available from CPAN and from
 L<http://www.veripool.org/verilog-perl>.
 
-Copyright 2000-2009 by Wilson Snyder.  This package is free software; you
+Copyright 2000-2010 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License Version 3 or the Perl Artistic License
 Version 2.0.
